@@ -157,7 +157,7 @@ class RopeMode(object):
     def pop_mark(self):
         self.env.pop_mark()
 
-    @decorators.local_command()
+    @decorators.local_function()
     def definition_location(self):
         definition = self._base_definition_location()
         if definition:
@@ -182,7 +182,7 @@ class RopeMode(object):
         self._check_project()
         self._base_show_doc(prefix, self._base_get_doc(codeassist.get_doc))
 
-    @decorators.local_command()
+    @decorators.local_function()
     def get_calltip(self):
         self._check_project()
         def _get_doc(project, text, offset, *args, **kwds):
@@ -203,7 +203,7 @@ class RopeMode(object):
         else:
             self.env.message('No docs available!')
 
-    @decorators.local_command()
+    @decorators.local_function()
     def get_doc(self):
         self._check_project()
         return self._base_get_doc(codeassist.get_doc)
@@ -275,11 +275,11 @@ class RopeMode(object):
     def auto_import(self):
         _CodeAssist(self, self.env).auto_import()
 
-    @decorators.local_command()
+    @decorators.local_function([])
     def completions(self):
         return _CodeAssist(self, self.env).completions()
 
-    @decorators.local_command()
+    @decorators.local_function([])
     def extended_completions(self):
         return _CodeAssist(self, self.env).extended_completions()
 
@@ -552,6 +552,18 @@ class Location(object):
             return self.location.lineno
         return self.location.resource.read().count('\n', 0, self.offset) + 1
 
+    @property
+    def line_content(self):
+        resource_contents = self.location.resource.read()
+        # rfind returns -1 for start of string, so by adding 1 we get the start
+        # of the string. When a match is found we want to exclude the matching
+        # character so again we add 1.
+        line_start = resource_contents.rfind("\n", 0, self.offset) + 1
+        line_end = resource_contents.find("\n", self.offset)
+        if line_end < 0:
+            line_end = len(resource_contents)
+        return resource_contents[line_start:line_end]
+
 
 class _CodeAssist(object):
 
